==> includable-1.17.0.tgz: package/lib/util.js <==
/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

'use strict'

const path = require('path')
const fs = require('fs')
const mkdirp = require('mkdirp')
const axios = require('axios')

const output = require('./output')
const Request = require('./http/Request')

module.exports = {
  output: output,

  request: function (method, fields, headers, options) {
    return new Request(method, fields, headers, options)
  },

  moduleJSON: function (boxName, authorName, authorNameFull, authorEmail, baseJSON) {
    if (!authorName || authorName === '') {
      authorName = '*author*'
    }
    if (!authorNameFull || authorNameFull === '') {
      authorNameFull = authorName
    }
    if (!authorEmail || authorEmail === '') {
      authorEmail = 'email@example.com'
    }

    if (!baseJSON) {
      baseJSON = {
        'license': 'proprietary',
        'controllers': {
          'web': 'web/index.php'
        }
      }
    }

    return Object.assign(baseJSON, {
      'slug': boxName,
      'name': authorName + '/' + boxName,
      'title': this.boxNameDisplay(boxName),
      'description': 'Includable app for ' + this.boxNameDisplay(boxName) + '.',
      'authors': [{
        'name': authorNameFull,
        'email': authorEmail
      }]
    })
  },

  capitalizeFirstLetter: function (string) {
    return string.charAt(0).toUpperCase() + string.slice(1)
  },

  boxNameDisplay: function (boxName) {
    return this.capitalizeFirstLetter(boxName.replace(/[-_]/gi, ' '))
  },

  getHomeDir: function () {
    var env = process.env

    if (process.platform === 'win32') {
      return this.getWin32HomeDir()
    }

    if ('HOME' in env && env.HOME) {
      return env.HOME
    }

    var user = this.getSystemUsername()

    if (user && process.platform === 'darwin') {
      return '/Users/' + user
    }

    if (process.getuid() === 0) {
      return '/root'
    }

    if (user) {
      return '/home/' + user
    }

    return process.cwd() || __dirname
  },

  getWin32HomeDir: function () {
    return process.env.USERPROFILE ||
      process.env.HOMEDRIVE + process.env.HOMEPATH ||
      process.env.HOME ||
      process.cwd()
  },

  getSystemUsername: function () {
    return process.env.LOGNAME ||
      process.env.USER ||
      process.env.LNAME ||
      process.env.USERNAME ||
      process.env.SUDO_USER ||
      process.env.C9_USER ||
      false
  },

  getPluginsDirectory: function (pluginsDirectory) {
    if (!pluginsDirectory) {
      pluginsDirectory = path.join(this.getHomeDir(), '.inc-plugins')
    }

    return pluginsDirectory
  },

  statOrNothing: function (origPath, event, cb) {
    if (event !== 'add' && event !== 'change' && event !== 'change') {
      cb(null, true)
      return
    }

    fs.stat(origPath, function (err) {
      cb(null, event === 'unlink' ? !!err : !err)
    })
  },

  downloadHelper: function (cb, basepath, force) {
    // Determine path
    var helperBasePath = path.join('.inc', 'meta')
    if (basepath) {
      helperBasePath = path.join(basepath, helperBasePath)
    }
    var helperFilename = path.join(helperBasePath, '.phpstorm.meta.php')

    // Check last updated timestamp
    fs.stat(helperFilename, function (err, info) {
      if (!err && !force && info.mtime.getTime() > (new Date()).getTime() - 3600000) {
        cb ? cb() : null
        return
      }

      // Download helper file
      axios.get(global.containerEndpoint + '/ide_helper').then(function (response) {
        if (!response.data) {
          cb()
          return
        }
        mkdirp(helperBasePath, function () {
          fs.writeFile(helperFilename, response.data, 'utf8', function () {
            if (cb) {
              cb()
            }
          })
        })
      })
    })

    // Delete old helper file
    var oldHelperFilename = '._scho' + 'lica_ide_helper.php'
    if (basepath) {
      oldHelperFilename = path.join(basepath, oldHelperFilename)
    }
    try {
      fs.unlinkSync(oldHelperFilename)
    } catch (e) {}
  }

}

==> includable-1.18.0.tgz: package/lib/util.js <==
/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

'use strict'

const path = require('path')
const fs = require('fs')
const mkdirp = require('mkdirp')
const axios = require('axios')

const output = require('./output')
const Request = require('./http/Request')

module.exports = {
  output: output,

  request: function (method, fields, headers, options) {
    return new Request(method, fields, headers, options)
  },

  moduleJSON: function (boxName, authorName, authorNameFull, authorEmail, baseJSON) {
    if (!authorName || authorName === '') {
      authorName = '*author*'
    }
    if (!authorNameFull || authorNameFull === '') {
      authorNameFull = authorName
    }
    if (!authorEmail || authorEmail === '') {
      authorEmail = 'email@example.com'
    }

    if (!baseJSON) {
      baseJSON = {
        'license': 'proprietary',
        'controllers': {
          'web': 'web/index.php'
        }
      }
    }

    return Object.assign(baseJSON, {
      'slug': boxName,
      'name': authorName + '/' + boxName,
      'title': this.boxNameDisplay(boxName),
      'description': 'Includable app for ' + this.boxNameDisplay(boxName) + '.',
      'authors': [{
        'name': authorNameFull,
        'email': authorEmail
      }]
    })
  },

  capitalizeFirstLetter: function (string) {
    return string.charAt(0).toUpperCase() + string.slice(1)
  },

  boxNameDisplay: function (boxName) {
    return this.capitalizeFirstLetter(boxName.replace(/[-_]/gi, ' '))
  },

  getHomeDir: function () {
    const env = process.env

    if (process.platform === 'win32') {
      return this.getWin32HomeDir()
    }

    if ('HOME' in env && env.HOME) {
      return env.HOME
    }

    const user = this.getSystemUsername()

    if (user && process.platform === 'darwin') {
      return '/Users/' + user
    }

    if (process.getuid() === 0) {
      return '/root'
    }

    if (user) {
      return '/home/' + user
    }

    return process.cwd() || __dirname
  },

  getWin32HomeDir: function () {
    return process.env.USERPROFILE ||
      process.env.HOMEDRIVE + process.env.HOMEPATH ||
      process.env.HOME ||
      process.cwd()
  },

  getSystemUsername: function () {
    return process.env.LOGNAME ||
      process.env.USER ||
      process.env.LNAME ||
      process.env.USERNAME ||
      process.env.SUDO_USER ||
      process.env.C9_USER ||
      false
  },

  getPluginsDirectory: function (pluginsDirectory) {
    if (!pluginsDirectory) {
      pluginsDirectory = path.join(this.getHomeDir(), '.inc-plugins')
    }

    return pluginsDirectory
  },

  statOrNothing: function (origPath, event, cb) {
    if (event !== 'add' && event !== 'change' && event !== 'change') {
      cb(null, true)
      return
    }

    fs.stat(origPath, function (err) {
      cb(null, event === 'unlink' ? !!err : !err)
    })
  },

  downloadHelper: function (cb, basepath, force) {
    // Determine path
    let helperBasePath = path.join('.inc', 'meta')
    if (basepath) {
      helperBasePath = path.join(basepath, helperBasePath)
    }
    const helperFilename = path.join(helperBasePath, '.phpstorm.meta.php')

    // Check last updated timestamp
    fs.stat(helperFilename, function (err, info) {
      if (!err && !force && info.mtime.getTime() > (new Date()).getTime() - 3600000) {
        cb && cb()
        return
      }

      // Download helper file
      axios.get(global.containerEndpoint + '/ide_helper').then((response) => {
        if (!response.data) {
          cb()
          return
        }
        mkdirp(helperBasePath, function () {
          fs.writeFile(helperFilename, response.data, 'utf8', () => cb && cb())
        })
      })
    })

    // Delete old helper file
    let oldHelperFilename = '._scho' + 'lica_ide_helper.php'
    if (basepath) {
      oldHelperFilename = path.join(basepath, oldHelperFilename)
    }
    try {
      fs.unlinkSync(oldHelperFilename)
    } catch (e) {}
  }

}
